@@ -1,16 +1,16 @@
 ;(function(){
   var map = {
-  "commitId": "9870ac8b926c529eb127c233f35781cacfa03f04",
-  "branchName": "release-client-6.2.x",
-  "buildTime": "2024-11-14 11:41:32 GMT",
-  "buildVersion": "1.0.1871",
+  "commitId": "f90c1b028b1a87946665bf232da3ee811751a346",
+  "branchName": "release-client-6.3.1",
+  "buildTime": "2024-12-20 09:24:17 GMT",
+  "buildVersion": "1.0.2145",
   "css": [
-    "@zoom/client-calendar-desktop/static/css/chunk-vendors.d9550452.css",
-    "@zoom/client-calendar-desktop/static/css/app.f179756b.css"
+    "@zoom/client-calendar-desktop/static/css/chunk-vendors.6fae82dc.css",
+    "@zoom/client-calendar-desktop/static/css/app.cc40dc41.css"
   ],
   "js": [
-    "@zoom/client-calendar-desktop/static/js/chunk-vendors.f0d56f7f.js",
-    "@zoom/client-calendar-desktop/static/js/app.8263d224.js"
+    "@zoom/client-calendar-desktop/static/js/chunk-vendors.fabb4ffd.js",
+    "@zoom/client-calendar-desktop/static/js/app.52b6cb75.js"
   ],
   "key": "@zoom/client-calendar-desktop"
 };
